@@ -1,11 +1,11 @@
 from pathlib import Path
-from typing import List
+from typing import Iterator, List
 
-from darwin.types import ExportParser, PathLike
+from darwin.datatypes import AnnotationFile, ExportParser, PathLike
 from darwin.utils import parse_darwin_json, split_video_annotation
 
 
-def darwin_to_dt_gen(file_paths):
+def darwin_to_dt_gen(file_paths: List[PathLike]) -> Iterator[AnnotationFile]:
     count = 0
     for file_path in map(Path, file_paths):
         files = file_path.glob("**/*") if file_path.is_dir() else [file_path]
@@ -24,9 +24,7 @@ def darwin_to_dt_gen(file_paths):
             count += 1
 
 
-def export_annotations(
-    exporter: ExportParser, file_paths: List[PathLike], output_directory: PathLike,
-):
+def export_annotations(exporter: ExportParser, file_paths: List[PathLike], output_directory: PathLike) -> None:
     """Converts a set of files to a different annotation format"""
     exporter(darwin_to_dt_gen(file_paths), Path(output_directory))
     print(f"Converted annotations saved at {output_directory}")
